@@ -1,10 +1,10 @@
 #!/usr/bin/env python -3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010 K. Richard Pixley.
+# Copyright 2010 - 2011 K. Richard Pixley.
 # See LICENSE for details.
 #
-# Time-stamp: <03-Jan-2011 19:42:41 PST by rich@noir.com>
+# Time-stamp: <01-Feb-2011 12:13:42 PST by rich@noir.com>
 
 """
 Elffile is a library which reads and writes `ELF format object files
@@ -179,7 +179,7 @@ class ElfFileIdent(StructBase):
 
     magic = None
     """
-    The magic 'number' which should be '\x1fELF' for all ELF format files. 
+    The magic 'number' which should be '\x7fELF' for all ELF format files. 
     """
 
     elfClass = None
@@ -216,7 +216,7 @@ class ElfFileIdent(StructBase):
     """
     A :py:class:`struct.Struct` (de)coder involving six fields:
 
-    * '\x1fELF', (Elf file magic number)
+    * '\x7fELF', (Elf file magic number)
     * ElfClass (32 vs 64-bit)
     * ElfData (endianness)
     * EV (file version)
@@ -671,6 +671,8 @@ class ElfFile(StructBase):
         # FIXME: need to handle order independence
         for this, that in zip(self.sectionHeaders, other.sectionHeaders):
             if this != that:
+                import sys
+                print('{0} differs from {1}'.format(this, that), file=sys.stderr)
                 return False
 
         return True
@@ -691,12 +693,33 @@ class ElfFile(StructBase):
 
         # FIXME: need to handle order independence
         for this, that in zip(self.sectionHeaders, other.sectionHeaders):
-            # on x86_64 linux, anyway
-            if (this.name == '.rela.debug_info' # x86_64 linux rela
-                or this.name == '.debug_str'    # x86_64 linux rela
-                or this.name == '.note.gnu.build-id' # x86_64 linux dyn
-                or this.name == '.debug_info' # x86_64 linux dyn
-                ):
+            if this.name in [
+                '.ARM.attributes',
+                '.ARM.exidx',
+                '.ARM.extab',
+                '.comment',
+                '.debug_aranges',
+                '.debug_frame',
+                '.debug_info',
+                '.debug_line',
+                '.debug_loc',
+                '.debug_pubnames',
+                '.debug_ranges',
+                '.debug_str',
+                '.note.GNU-stack',
+                '.rel.ARM.exidx',
+                '.rel.debug_aranges',
+                '.rel.debug_frame',
+                '.rel.debug_info',
+                '.rel.debug_line',
+                '.rel.debug_pubnames',
+                '.rel.text',
+                '.rodata',
+                '.rodata.str1.4',
+                '.shstrtab',
+                '.strtab',
+                '.symtab',
+                ]:
                 continue
 
             if not this.close_enough(that):
@@ -856,7 +879,7 @@ class ElfFileHeader(StructBase):
                 and self.version == other.version
                 and self.entry == other.entry
                 and self.phoff == other.phoff
-                and self.shoff == other.shoff
+                # and self.shoff == other.shoff
                 and self.flags == other.flags
                 and self.ehsize == other.ehsize
                 and self.phentsize == other.phentsize
